package com.persagy.dmp.rwd.edit.entity;

import com.persagy.dmp.rwd.edit.enumeration.EnumOperationType;
import com.persagy.dmp.rwd.edit.model.ClassDefChangeRecordModel;
import com.persagy.dmp.rwd.enums.ObjType;
import com.vladmihalcea.hibernate.type.json.JsonStringType;
import lombok.Getter;
import lombok.Setter;
import org.hibernate.annotations.SQLDelete;
import org.hibernate.annotations.TypeDef;
import org.hibernate.annotations.Where;

import javax.persistence.*;
import java.util.Date;

@Setter
@Getter
@Entity
@Table(name = "rwd_def_class_change_record")
@TypeDef(name = "json", typeClass = JsonStringType.class)
@Where(clause = "valid = 1")
@SQLDelete(sql = "update rwd_def_class_change_record set valid = 0 where id = ?")
public class ClassDefChangeRecord {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Integer id;
    private String code;
    private String groupCode;
    @Enumerated(value = EnumType.STRING)
    private ObjType objType;
    private String name;
    private String aliasCode;
    private String aliasName;
    private String type;
    private String projectId;
    private String majorCode;
    private String systemCode;
    private String equipmentCode;
    private String parentCode;
    @Enumerated(EnumType.STRING)
    private EnumOperationType operationType;//操作类型
    private String operationUser;//操作人
    private Date operationTime;//操作时间
    private String confirmUser;//确认人
    private Date confirmTime;//确认时间
    private String publishUser;//发布人
    private Date publishTime;//发布时间
    private Date finishTime;//完成时间
    private Boolean valid;//true 正常 false 失效
    private Integer state;//状态 0.取消 1.初始化 2.确认 3.发布 4.完成

    public ClassDefChangeRecordModel toModel() {
        ClassDefChangeRecordModel model = new ClassDefChangeRecordModel();
        model.setId(this.id);
        model.setCode(this.code);
        model.setGroupCode(this.groupCode);
        model.setObjType(this.objType);
        model.setName(this.name);
        model.setAliasCode(this.aliasCode);
        model.setAliasName(this.aliasName);
        model.setType(this.type);
        model.setProjectId(this.projectId);
        model.setMajorCode(this.majorCode);
        model.setSystemCode(this.systemCode);
        model.setEquipmentCode(this.equipmentCode);
        model.setParentCode(this.parentCode);
        model.setOperationType(this.operationType);
        model.setOperationUser(this.operationUser);
        model.setOperationTime(this.operationTime);
        model.setConfirmUser(this.confirmUser);
        model.setConfirmTime(this.confirmTime);
        model.setPublishUser(this.publishUser);
        model.setPublishTime(this.publishTime);
        model.setFinishTime(this.finishTime);
        model.setValid(this.valid);
        model.setState(this.state);
        return model;
    }
}
